@@ -3,11 +3,12 @@ Contains utilities and constants that control how the app handles regex
 """
 
 import re
+from typing import Callable
 
 from logria.utilities.constants import ANSI_COLOR_PATTERN
 
 
-def regex_test_generator(pattern: str) -> callable:
+def regex_test_generator(pattern: str) -> Callable:
     """
     Return a function that will test a string against `pattern`
     Ignores characters in ANSI color escape codes
